# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class IntegrationEvent(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IntegrationEvent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'self_uri': 'str',
            'correlation_id': 'str',
            'timestamp': 'datetime',
            'level': 'str',
            'event_code': 'str',
            'message': 'MessageInfo',
            'entities': 'list[EventEntity]',
            'context_attributes': 'dict(str, str)',
            'detail_message': 'MessageInfo',
            'user': 'User'
        }

        self.attribute_map = {
            'id': 'id',
            'self_uri': 'selfUri',
            'correlation_id': 'correlationId',
            'timestamp': 'timestamp',
            'level': 'level',
            'event_code': 'eventCode',
            'message': 'message',
            'entities': 'entities',
            'context_attributes': 'contextAttributes',
            'detail_message': 'detailMessage',
            'user': 'user'
        }

        self._id = None
        self._self_uri = None
        self._correlation_id = None
        self._timestamp = None
        self._level = None
        self._event_code = None
        self._message = None
        self._entities = None
        self._context_attributes = None
        self._detail_message = None
        self._user = None

    @property
    def id(self):
        """
        Gets the id of this IntegrationEvent.
        Unique ID for this event

        :return: The id of this IntegrationEvent.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IntegrationEvent.
        Unique ID for this event

        :param id: The id of this IntegrationEvent.
        :type: str
        """
        
        self._id = id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IntegrationEvent.
        The URI for this object

        :return: The self_uri of this IntegrationEvent.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IntegrationEvent.
        The URI for this object

        :param self_uri: The self_uri of this IntegrationEvent.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def correlation_id(self):
        """
        Gets the correlation_id of this IntegrationEvent.
        Correlation ID for the event

        :return: The correlation_id of this IntegrationEvent.
        :rtype: str
        """
        return self._correlation_id

    @correlation_id.setter
    def correlation_id(self, correlation_id):
        """
        Sets the correlation_id of this IntegrationEvent.
        Correlation ID for the event

        :param correlation_id: The correlation_id of this IntegrationEvent.
        :type: str
        """
        
        self._correlation_id = correlation_id

    @property
    def timestamp(self):
        """
        Gets the timestamp of this IntegrationEvent.
        Time the event occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The timestamp of this IntegrationEvent.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this IntegrationEvent.
        Time the event occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param timestamp: The timestamp of this IntegrationEvent.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def level(self):
        """
        Gets the level of this IntegrationEvent.
        Indicates the severity of the event.

        :return: The level of this IntegrationEvent.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this IntegrationEvent.
        Indicates the severity of the event.

        :param level: The level of this IntegrationEvent.
        :type: str
        """
        allowed_values = ["INFO", "WARN", "ERROR", "CRITICAL"]
        if level.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for level -> " + level)
            self._level = "outdated_sdk_version"
        else:
            self._level = level

    @property
    def event_code(self):
        """
        Gets the event_code of this IntegrationEvent.
        A classification for the event. Suitable for programmatic searching, sorting, or filtering

        :return: The event_code of this IntegrationEvent.
        :rtype: str
        """
        return self._event_code

    @event_code.setter
    def event_code(self, event_code):
        """
        Sets the event_code of this IntegrationEvent.
        A classification for the event. Suitable for programmatic searching, sorting, or filtering

        :param event_code: The event_code of this IntegrationEvent.
        :type: str
        """
        
        self._event_code = event_code

    @property
    def message(self):
        """
        Gets the message of this IntegrationEvent.
        Message indicating what happened

        :return: The message of this IntegrationEvent.
        :rtype: MessageInfo
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this IntegrationEvent.
        Message indicating what happened

        :param message: The message of this IntegrationEvent.
        :type: MessageInfo
        """
        
        self._message = message

    @property
    def entities(self):
        """
        Gets the entities of this IntegrationEvent.
        Collection of entities affected by or pertaining to the event (e.g. a list of Integrations or Bridge connectors)

        :return: The entities of this IntegrationEvent.
        :rtype: list[EventEntity]
        """
        return self._entities

    @entities.setter
    def entities(self, entities):
        """
        Sets the entities of this IntegrationEvent.
        Collection of entities affected by or pertaining to the event (e.g. a list of Integrations or Bridge connectors)

        :param entities: The entities of this IntegrationEvent.
        :type: list[EventEntity]
        """
        
        self._entities = entities

    @property
    def context_attributes(self):
        """
        Gets the context_attributes of this IntegrationEvent.
        Map of context attributes specific to this event.

        :return: The context_attributes of this IntegrationEvent.
        :rtype: dict(str, str)
        """
        return self._context_attributes

    @context_attributes.setter
    def context_attributes(self, context_attributes):
        """
        Sets the context_attributes of this IntegrationEvent.
        Map of context attributes specific to this event.

        :param context_attributes: The context_attributes of this IntegrationEvent.
        :type: dict(str, str)
        """
        
        self._context_attributes = context_attributes

    @property
    def detail_message(self):
        """
        Gets the detail_message of this IntegrationEvent.
        Message with additional details about the event. (e.g. an exception cause.)

        :return: The detail_message of this IntegrationEvent.
        :rtype: MessageInfo
        """
        return self._detail_message

    @detail_message.setter
    def detail_message(self, detail_message):
        """
        Sets the detail_message of this IntegrationEvent.
        Message with additional details about the event. (e.g. an exception cause.)

        :param detail_message: The detail_message of this IntegrationEvent.
        :type: MessageInfo
        """
        
        self._detail_message = detail_message

    @property
    def user(self):
        """
        Gets the user of this IntegrationEvent.
        User that took an action that resulted in the event.

        :return: The user of this IntegrationEvent.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this IntegrationEvent.
        User that took an action that resulted in the event.

        :param user: The user of this IntegrationEvent.
        :type: User
        """
        
        self._user = user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Message(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Message - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'held': 'bool',
            'segments': 'list[Segment]',
            'direction': 'str',
            'recording_id': 'str',
            'error_info': 'ErrorBody',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'start_alerting_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'provider': 'str',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'to_address': 'Address',
            'from_address': 'Address',
            'messages': 'list[MessageDetails]',
            'journey_context': 'JourneyContext',
            'wrapup': 'Wrapup',
            'after_call_work': 'AfterCallWork',
            'after_call_work_required': 'bool'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'held': 'held',
            'segments': 'segments',
            'direction': 'direction',
            'recording_id': 'recordingId',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'start_alerting_time': 'startAlertingTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'provider': 'provider',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'to_address': 'toAddress',
            'from_address': 'fromAddress',
            'messages': 'messages',
            'journey_context': 'journeyContext',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired'
        }

        self._state = None
        self._id = None
        self._held = None
        self._segments = None
        self._direction = None
        self._recording_id = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._start_alerting_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._provider = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None
        self._script_id = None
        self._peer_id = None
        self._to_address = None
        self._from_address = None
        self._messages = None
        self._journey_context = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None

    @property
    def state(self):
        """
        Gets the state of this Message.
        The connection state of this communication.

        :return: The state of this Message.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Message.
        The connection state of this communication.

        :param state: The state of this Message.
        :type: str
        """
        allowed_values = ["alerting", "connected", "disconnected"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this Message.
        A globally unique identifier for this communication.

        :return: The id of this Message.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Message.
        A globally unique identifier for this communication.

        :param id: The id of this Message.
        :type: str
        """
        
        self._id = id

    @property
    def held(self):
        """
        Gets the held of this Message.
        True if this call is held and the person on this side hears silence.

        :return: The held of this Message.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this Message.
        True if this call is held and the person on this side hears silence.

        :param held: The held of this Message.
        :type: bool
        """
        
        self._held = held

    @property
    def segments(self):
        """
        Gets the segments of this Message.
        The time line of the participant's message, divided into activity segments.

        :return: The segments of this Message.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this Message.
        The time line of the participant's message, divided into activity segments.

        :param segments: The segments of this Message.
        :type: list[Segment]
        """
        
        self._segments = segments

    @property
    def direction(self):
        """
        Gets the direction of this Message.
        The direction of the message.

        :return: The direction of this Message.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this Message.
        The direction of the message.

        :param direction: The direction of this Message.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def recording_id(self):
        """
        Gets the recording_id of this Message.
        A globally unique identifier for the recording associated with this message.

        :return: The recording_id of this Message.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this Message.
        A globally unique identifier for the recording associated with this message.

        :param recording_id: The recording_id of this Message.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def error_info(self):
        """
        Gets the error_info of this Message.


        :return: The error_info of this Message.
        :rtype: ErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this Message.


        :param error_info: The error_info of this Message.
        :type: ErrorBody
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Message.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :return: The disconnect_type of this Message.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Message.
        System defined string indicating what caused the communication to disconnect. Will be null until the communication disconnects.

        :param disconnect_type: The disconnect_type of this Message.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "timeout", "transfer", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this Message.
        The timestamp the message was placed on hold in the cloud clock if the message is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_hold_time of this Message.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this Message.
        The timestamp the message was placed on hold in the cloud clock if the message is currently on hold. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_hold_time: The start_hold_time of this Message.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def start_alerting_time(self):
        """
        Gets the start_alerting_time of this Message.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_alerting_time of this Message.
        :rtype: datetime
        """
        return self._start_alerting_time

    @start_alerting_time.setter
    def start_alerting_time(self, start_alerting_time):
        """
        Sets the start_alerting_time of this Message.
        The timestamp the communication has when it is first put into an alerting state. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_alerting_time: The start_alerting_time of this Message.
        :type: datetime
        """
        
        self._start_alerting_time = start_alerting_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Message.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The connected_time of this Message.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Message.
        The timestamp when this communication was connected in the cloud clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param connected_time: The connected_time of this Message.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Message.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The disconnected_time of this Message.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Message.
        The timestamp when this communication disconnected from the conversation in the provider clock. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param disconnected_time: The disconnected_time of this Message.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def provider(self):
        """
        Gets the provider of this Message.
        The source provider for the message.

        :return: The provider of this Message.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this Message.
        The source provider for the message.

        :param provider: The provider of this Message.
        :type: str
        """
        
        self._provider = provider

    @property
    def type(self):
        """
        Gets the type of this Message.
        Indicates the type of message platform from which the message originated.

        :return: The type of this Message.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Message.
        Indicates the type of message platform from which the message originated.

        :param type: The type of this Message.
        :type: str
        """
        allowed_values = ["unknown", "sms", "twitter", "facebook", "line", "whatsapp", "telegram", "kakao", "webmessaging"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this Message.
        Indicates the country where the recipient is associated in ISO 3166-1 alpha-2 format.

        :return: The recipient_country of this Message.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this Message.
        Indicates the country where the recipient is associated in ISO 3166-1 alpha-2 format.

        :param recipient_country: The recipient_country of this Message.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this Message.
        The type of the recipient. Eg: Provisioned phoneNumber is the recipient for sms message type.

        :return: The recipient_type of this Message.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this Message.
        The type of the recipient. Eg: Provisioned phoneNumber is the recipient for sms message type.

        :param recipient_type: The recipient_type of this Message.
        :type: str
        """
        
        self._recipient_type = recipient_type

    @property
    def script_id(self):
        """
        Gets the script_id of this Message.
        The UUID of the script to use.

        :return: The script_id of this Message.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this Message.
        The UUID of the script to use.

        :param script_id: The script_id of this Message.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this Message.
        The id of the peer communication corresponding to a matching leg for this communication.

        :return: The peer_id of this Message.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this Message.
        The id of the peer communication corresponding to a matching leg for this communication.

        :param peer_id: The peer_id of this Message.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def to_address(self):
        """
        Gets the to_address of this Message.
        Address and name data for a call endpoint.

        :return: The to_address of this Message.
        :rtype: Address
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this Message.
        Address and name data for a call endpoint.

        :param to_address: The to_address of this Message.
        :type: Address
        """
        
        self._to_address = to_address

    @property
    def from_address(self):
        """
        Gets the from_address of this Message.
        Address and name data for a call endpoint.

        :return: The from_address of this Message.
        :rtype: Address
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this Message.
        Address and name data for a call endpoint.

        :param from_address: The from_address of this Message.
        :type: Address
        """
        
        self._from_address = from_address

    @property
    def messages(self):
        """
        Gets the messages of this Message.
        The messages sent on this communication channel.

        :return: The messages of this Message.
        :rtype: list[MessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this Message.
        The messages sent on this communication channel.

        :param messages: The messages of this Message.
        :type: list[MessageDetails]
        """
        
        self._messages = messages

    @property
    def journey_context(self):
        """
        Gets the journey_context of this Message.
        A subset of the Journey System's data relevant to a part of a conversation (for external linkage and internal usage/context).

        :return: The journey_context of this Message.
        :rtype: JourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this Message.
        A subset of the Journey System's data relevant to a part of a conversation (for external linkage and internal usage/context).

        :param journey_context: The journey_context of this Message.
        :type: JourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def wrapup(self):
        """
        Gets the wrapup of this Message.
        Call wrap up or disposition data.

        :return: The wrapup of this Message.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this Message.
        Call wrap up or disposition data.

        :param wrapup: The wrapup of this Message.
        :type: Wrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this Message.
        After-call work for the communication.

        :return: The after_call_work of this Message.
        :rtype: AfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this Message.
        After-call work for the communication.

        :param after_call_work: The after_call_work of this Message.
        :type: AfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this Message.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :return: The after_call_work_required of this Message.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this Message.
        Indicates if after-call work is required for a communication. Only used when the ACW Setting is Agent Requested.

        :param after_call_work_required: The after_call_work_required of this Message.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KnowledgeDocument(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KnowledgeDocument - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'language_code': 'str',
            'type': 'str',
            'faq': 'DocumentFaq',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'categories': 'list[KnowledgeCategory]',
            'knowledge_base': 'KnowledgeBase',
            'external_url': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'language_code': 'languageCode',
            'type': 'type',
            'faq': 'faq',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'categories': 'categories',
            'knowledge_base': 'knowledgeBase',
            'external_url': 'externalUrl',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._language_code = None
        self._type = None
        self._faq = None
        self._date_created = None
        self._date_modified = None
        self._categories = None
        self._knowledge_base = None
        self._external_url = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this KnowledgeDocument.
        The globally unique identifier for the object.

        :return: The id of this KnowledgeDocument.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KnowledgeDocument.
        The globally unique identifier for the object.

        :param id: The id of this KnowledgeDocument.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this KnowledgeDocument.


        :return: The name of this KnowledgeDocument.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this KnowledgeDocument.


        :param name: The name of this KnowledgeDocument.
        :type: str
        """
        
        self._name = name

    @property
    def language_code(self):
        """
        Gets the language_code of this KnowledgeDocument.
        Language of the document

        :return: The language_code of this KnowledgeDocument.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this KnowledgeDocument.
        Language of the document

        :param language_code: The language_code of this KnowledgeDocument.
        :type: str
        """
        allowed_values = ["en-US", "de-DE"]
        if language_code.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for language_code -> " + language_code)
            self._language_code = "outdated_sdk_version"
        else:
            self._language_code = language_code

    @property
    def type(self):
        """
        Gets the type of this KnowledgeDocument.
        Document type

        :return: The type of this KnowledgeDocument.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this KnowledgeDocument.
        Document type

        :param type: The type of this KnowledgeDocument.
        :type: str
        """
        allowed_values = ["Faq"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def faq(self):
        """
        Gets the faq of this KnowledgeDocument.
        FAQ document details

        :return: The faq of this KnowledgeDocument.
        :rtype: DocumentFaq
        """
        return self._faq

    @faq.setter
    def faq(self, faq):
        """
        Sets the faq of this KnowledgeDocument.
        FAQ document details

        :param faq: The faq of this KnowledgeDocument.
        :type: DocumentFaq
        """
        
        self._faq = faq

    @property
    def date_created(self):
        """
        Gets the date_created of this KnowledgeDocument.
        Document creation date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this KnowledgeDocument.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this KnowledgeDocument.
        Document creation date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this KnowledgeDocument.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this KnowledgeDocument.
        Document last modification date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this KnowledgeDocument.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this KnowledgeDocument.
        Document last modification date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this KnowledgeDocument.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def categories(self):
        """
        Gets the categories of this KnowledgeDocument.
        Document categories

        :return: The categories of this KnowledgeDocument.
        :rtype: list[KnowledgeCategory]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """
        Sets the categories of this KnowledgeDocument.
        Document categories

        :param categories: The categories of this KnowledgeDocument.
        :type: list[KnowledgeCategory]
        """
        
        self._categories = categories

    @property
    def knowledge_base(self):
        """
        Gets the knowledge_base of this KnowledgeDocument.
        Knowledge base which document does belong to

        :return: The knowledge_base of this KnowledgeDocument.
        :rtype: KnowledgeBase
        """
        return self._knowledge_base

    @knowledge_base.setter
    def knowledge_base(self, knowledge_base):
        """
        Sets the knowledge_base of this KnowledgeDocument.
        Knowledge base which document does belong to

        :param knowledge_base: The knowledge_base of this KnowledgeDocument.
        :type: KnowledgeBase
        """
        
        self._knowledge_base = knowledge_base

    @property
    def external_url(self):
        """
        Gets the external_url of this KnowledgeDocument.
        External URL to the document

        :return: The external_url of this KnowledgeDocument.
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """
        Sets the external_url of this KnowledgeDocument.
        External URL to the document

        :param external_url: The external_url of this KnowledgeDocument.
        :type: str
        """
        
        self._external_url = external_url

    @property
    def self_uri(self):
        """
        Gets the self_uri of this KnowledgeDocument.
        The URI for this object

        :return: The self_uri of this KnowledgeDocument.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this KnowledgeDocument.
        The URI for this object

        :param self_uri: The self_uri of this KnowledgeDocument.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationVideoEventTopicEmail(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationVideoEventTopicEmail - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'held': 'bool',
            'auto_generated': 'bool',
            'subject': 'str',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'messages_sent': 'int',
            'error_info': 'QueueConversationVideoEventTopicErrorDetails',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'message_id': 'str',
            'direction': 'str',
            'draft_attachments': 'list[QueueConversationVideoEventTopicAttachment]',
            'spam': 'bool',
            'wrapup': 'QueueConversationVideoEventTopicWrapup',
            'after_call_work': 'QueueConversationVideoEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'held': 'held',
            'auto_generated': 'autoGenerated',
            'subject': 'subject',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'messages_sent': 'messagesSent',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'message_id': 'messageId',
            'direction': 'direction',
            'draft_attachments': 'draftAttachments',
            'spam': 'spam',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._held = None
        self._auto_generated = None
        self._subject = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._messages_sent = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._message_id = None
        self._direction = None
        self._draft_attachments = None
        self._spam = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationVideoEventTopicEmail.


        :return: The id of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationVideoEventTopicEmail.


        :param id: The id of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationVideoEventTopicEmail.


        :return: The state of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationVideoEventTopicEmail.


        :param state: The state of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        allowed_values = ["ALERTING", "CONNECTED", "DISCONNECTED", "NONE", "TRANSMITTING"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def held(self):
        """
        Gets the held of this QueueConversationVideoEventTopicEmail.


        :return: The held of this QueueConversationVideoEventTopicEmail.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationVideoEventTopicEmail.


        :param held: The held of this QueueConversationVideoEventTopicEmail.
        :type: bool
        """
        
        self._held = held

    @property
    def auto_generated(self):
        """
        Gets the auto_generated of this QueueConversationVideoEventTopicEmail.


        :return: The auto_generated of this QueueConversationVideoEventTopicEmail.
        :rtype: bool
        """
        return self._auto_generated

    @auto_generated.setter
    def auto_generated(self, auto_generated):
        """
        Sets the auto_generated of this QueueConversationVideoEventTopicEmail.


        :param auto_generated: The auto_generated of this QueueConversationVideoEventTopicEmail.
        :type: bool
        """
        
        self._auto_generated = auto_generated

    @property
    def subject(self):
        """
        Gets the subject of this QueueConversationVideoEventTopicEmail.


        :return: The subject of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """
        Sets the subject of this QueueConversationVideoEventTopicEmail.


        :param subject: The subject of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._subject = subject

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationVideoEventTopicEmail.


        :return: The provider of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationVideoEventTopicEmail.


        :param provider: The provider of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationVideoEventTopicEmail.


        :return: The script_id of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationVideoEventTopicEmail.


        :param script_id: The script_id of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationVideoEventTopicEmail.


        :return: The peer_id of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationVideoEventTopicEmail.


        :param peer_id: The peer_id of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def messages_sent(self):
        """
        Gets the messages_sent of this QueueConversationVideoEventTopicEmail.


        :return: The messages_sent of this QueueConversationVideoEventTopicEmail.
        :rtype: int
        """
        return self._messages_sent

    @messages_sent.setter
    def messages_sent(self, messages_sent):
        """
        Sets the messages_sent of this QueueConversationVideoEventTopicEmail.


        :param messages_sent: The messages_sent of this QueueConversationVideoEventTopicEmail.
        :type: int
        """
        
        self._messages_sent = messages_sent

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationVideoEventTopicEmail.


        :return: The error_info of this QueueConversationVideoEventTopicEmail.
        :rtype: QueueConversationVideoEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationVideoEventTopicEmail.


        :param error_info: The error_info of this QueueConversationVideoEventTopicEmail.
        :type: QueueConversationVideoEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationVideoEventTopicEmail.


        :return: The disconnect_type of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationVideoEventTopicEmail.


        :param disconnect_type: The disconnect_type of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationVideoEventTopicEmail.


        :return: The start_hold_time of this QueueConversationVideoEventTopicEmail.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationVideoEventTopicEmail.


        :param start_hold_time: The start_hold_time of this QueueConversationVideoEventTopicEmail.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationVideoEventTopicEmail.


        :return: The connected_time of this QueueConversationVideoEventTopicEmail.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationVideoEventTopicEmail.


        :param connected_time: The connected_time of this QueueConversationVideoEventTopicEmail.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationVideoEventTopicEmail.


        :return: The disconnected_time of this QueueConversationVideoEventTopicEmail.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationVideoEventTopicEmail.


        :param disconnected_time: The disconnected_time of this QueueConversationVideoEventTopicEmail.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def message_id(self):
        """
        Gets the message_id of this QueueConversationVideoEventTopicEmail.


        :return: The message_id of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._message_id

    @message_id.setter
    def message_id(self, message_id):
        """
        Sets the message_id of this QueueConversationVideoEventTopicEmail.


        :param message_id: The message_id of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        
        self._message_id = message_id

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationVideoEventTopicEmail.


        :return: The direction of this QueueConversationVideoEventTopicEmail.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationVideoEventTopicEmail.


        :param direction: The direction of this QueueConversationVideoEventTopicEmail.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def draft_attachments(self):
        """
        Gets the draft_attachments of this QueueConversationVideoEventTopicEmail.


        :return: The draft_attachments of this QueueConversationVideoEventTopicEmail.
        :rtype: list[QueueConversationVideoEventTopicAttachment]
        """
        return self._draft_attachments

    @draft_attachments.setter
    def draft_attachments(self, draft_attachments):
        """
        Sets the draft_attachments of this QueueConversationVideoEventTopicEmail.


        :param draft_attachments: The draft_attachments of this QueueConversationVideoEventTopicEmail.
        :type: list[QueueConversationVideoEventTopicAttachment]
        """
        
        self._draft_attachments = draft_attachments

    @property
    def spam(self):
        """
        Gets the spam of this QueueConversationVideoEventTopicEmail.


        :return: The spam of this QueueConversationVideoEventTopicEmail.
        :rtype: bool
        """
        return self._spam

    @spam.setter
    def spam(self, spam):
        """
        Sets the spam of this QueueConversationVideoEventTopicEmail.


        :param spam: The spam of this QueueConversationVideoEventTopicEmail.
        :type: bool
        """
        
        self._spam = spam

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationVideoEventTopicEmail.


        :return: The wrapup of this QueueConversationVideoEventTopicEmail.
        :rtype: QueueConversationVideoEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationVideoEventTopicEmail.


        :param wrapup: The wrapup of this QueueConversationVideoEventTopicEmail.
        :type: QueueConversationVideoEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationVideoEventTopicEmail.


        :return: The after_call_work of this QueueConversationVideoEventTopicEmail.
        :rtype: QueueConversationVideoEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationVideoEventTopicEmail.


        :param after_call_work: The after_call_work of this QueueConversationVideoEventTopicEmail.
        :type: QueueConversationVideoEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationVideoEventTopicEmail.


        :return: The after_call_work_required of this QueueConversationVideoEventTopicEmail.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationVideoEventTopicEmail.


        :param after_call_work_required: The after_call_work_required of this QueueConversationVideoEventTopicEmail.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationVideoEventTopicEmail.


        :return: The additional_properties of this QueueConversationVideoEventTopicEmail.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationVideoEventTopicEmail.


        :param additional_properties: The additional_properties of this QueueConversationVideoEventTopicEmail.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserRecording(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserRecording - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'content_uri': 'str',
            'workspace': 'DomainEntityRef',
            'created_by': 'DomainEntityRef',
            'conversation': 'Conversation',
            'content_length': 'int',
            'duration_milliseconds': 'int',
            'thumbnails': 'list[DocumentThumbnail]',
            'read': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'content_uri': 'contentUri',
            'workspace': 'workspace',
            'created_by': 'createdBy',
            'conversation': 'conversation',
            'content_length': 'contentLength',
            'duration_milliseconds': 'durationMilliseconds',
            'thumbnails': 'thumbnails',
            'read': 'read',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._content_uri = None
        self._workspace = None
        self._created_by = None
        self._conversation = None
        self._content_length = None
        self._duration_milliseconds = None
        self._thumbnails = None
        self._read = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UserRecording.
        The globally unique identifier for the object.

        :return: The id of this UserRecording.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserRecording.
        The globally unique identifier for the object.

        :param id: The id of this UserRecording.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UserRecording.


        :return: The name of this UserRecording.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserRecording.


        :param name: The name of this UserRecording.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this UserRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this UserRecording.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this UserRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this UserRecording.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this UserRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this UserRecording.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this UserRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this UserRecording.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def content_uri(self):
        """
        Gets the content_uri of this UserRecording.


        :return: The content_uri of this UserRecording.
        :rtype: str
        """
        return self._content_uri

    @content_uri.setter
    def content_uri(self, content_uri):
        """
        Sets the content_uri of this UserRecording.


        :param content_uri: The content_uri of this UserRecording.
        :type: str
        """
        
        self._content_uri = content_uri

    @property
    def workspace(self):
        """
        Gets the workspace of this UserRecording.


        :return: The workspace of this UserRecording.
        :rtype: DomainEntityRef
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this UserRecording.


        :param workspace: The workspace of this UserRecording.
        :type: DomainEntityRef
        """
        
        self._workspace = workspace

    @property
    def created_by(self):
        """
        Gets the created_by of this UserRecording.


        :return: The created_by of this UserRecording.
        :rtype: DomainEntityRef
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this UserRecording.


        :param created_by: The created_by of this UserRecording.
        :type: DomainEntityRef
        """
        
        self._created_by = created_by

    @property
    def conversation(self):
        """
        Gets the conversation of this UserRecording.


        :return: The conversation of this UserRecording.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this UserRecording.


        :param conversation: The conversation of this UserRecording.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def content_length(self):
        """
        Gets the content_length of this UserRecording.


        :return: The content_length of this UserRecording.
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """
        Sets the content_length of this UserRecording.


        :param content_length: The content_length of this UserRecording.
        :type: int
        """
        
        self._content_length = content_length

    @property
    def duration_milliseconds(self):
        """
        Gets the duration_milliseconds of this UserRecording.


        :return: The duration_milliseconds of this UserRecording.
        :rtype: int
        """
        return self._duration_milliseconds

    @duration_milliseconds.setter
    def duration_milliseconds(self, duration_milliseconds):
        """
        Sets the duration_milliseconds of this UserRecording.


        :param duration_milliseconds: The duration_milliseconds of this UserRecording.
        :type: int
        """
        
        self._duration_milliseconds = duration_milliseconds

    @property
    def thumbnails(self):
        """
        Gets the thumbnails of this UserRecording.


        :return: The thumbnails of this UserRecording.
        :rtype: list[DocumentThumbnail]
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        """
        Sets the thumbnails of this UserRecording.


        :param thumbnails: The thumbnails of this UserRecording.
        :type: list[DocumentThumbnail]
        """
        
        self._thumbnails = thumbnails

    @property
    def read(self):
        """
        Gets the read of this UserRecording.


        :return: The read of this UserRecording.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this UserRecording.


        :param read: The read of this UserRecording.
        :type: bool
        """
        
        self._read = read

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UserRecording.
        The URI for this object

        :return: The self_uri of this UserRecording.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UserRecording.
        The URI for this object

        :param self_uri: The self_uri of this UserRecording.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsEvaluation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsEvaluation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'evaluation_id': 'str',
            'evaluator_id': 'str',
            'user_id': 'str',
            'event_time': 'datetime',
            'queue_id': 'str',
            'form_id': 'str',
            'context_id': 'str',
            'form_name': 'str',
            'calibration_id': 'str',
            'rescored': 'bool',
            'deleted': 'bool',
            'o_total_score': 'int',
            'o_total_critical_score': 'int'
        }

        self.attribute_map = {
            'evaluation_id': 'evaluationId',
            'evaluator_id': 'evaluatorId',
            'user_id': 'userId',
            'event_time': 'eventTime',
            'queue_id': 'queueId',
            'form_id': 'formId',
            'context_id': 'contextId',
            'form_name': 'formName',
            'calibration_id': 'calibrationId',
            'rescored': 'rescored',
            'deleted': 'deleted',
            'o_total_score': 'oTotalScore',
            'o_total_critical_score': 'oTotalCriticalScore'
        }

        self._evaluation_id = None
        self._evaluator_id = None
        self._user_id = None
        self._event_time = None
        self._queue_id = None
        self._form_id = None
        self._context_id = None
        self._form_name = None
        self._calibration_id = None
        self._rescored = None
        self._deleted = None
        self._o_total_score = None
        self._o_total_critical_score = None

    @property
    def evaluation_id(self):
        """
        Gets the evaluation_id of this AnalyticsEvaluation.
        Unique identifier for the evaluation

        :return: The evaluation_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._evaluation_id

    @evaluation_id.setter
    def evaluation_id(self, evaluation_id):
        """
        Sets the evaluation_id of this AnalyticsEvaluation.
        Unique identifier for the evaluation

        :param evaluation_id: The evaluation_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._evaluation_id = evaluation_id

    @property
    def evaluator_id(self):
        """
        Gets the evaluator_id of this AnalyticsEvaluation.
        A unique identifier of the PureCloud user who evaluated the interaction

        :return: The evaluator_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._evaluator_id

    @evaluator_id.setter
    def evaluator_id(self, evaluator_id):
        """
        Sets the evaluator_id of this AnalyticsEvaluation.
        A unique identifier of the PureCloud user who evaluated the interaction

        :param evaluator_id: The evaluator_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._evaluator_id = evaluator_id

    @property
    def user_id(self):
        """
        Gets the user_id of this AnalyticsEvaluation.
        Unique identifier for the user being evaluated

        :return: The user_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AnalyticsEvaluation.
        Unique identifier for the user being evaluated

        :param user_id: The user_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def event_time(self):
        """
        Gets the event_time of this AnalyticsEvaluation.
        Specifies when an evaluation occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The event_time of this AnalyticsEvaluation.
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this AnalyticsEvaluation.
        Specifies when an evaluation occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param event_time: The event_time of this AnalyticsEvaluation.
        :type: datetime
        """
        
        self._event_time = event_time

    @property
    def queue_id(self):
        """
        Gets the queue_id of this AnalyticsEvaluation.
        Unique identifier for the queue the conversation was on

        :return: The queue_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this AnalyticsEvaluation.
        Unique identifier for the queue the conversation was on

        :param queue_id: The queue_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def form_id(self):
        """
        Gets the form_id of this AnalyticsEvaluation.
        Unique identifier for the form used to evaluate the conversation/agent

        :return: The form_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """
        Sets the form_id of this AnalyticsEvaluation.
        Unique identifier for the form used to evaluate the conversation/agent

        :param form_id: The form_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._form_id = form_id

    @property
    def context_id(self):
        """
        Gets the context_id of this AnalyticsEvaluation.
        A unique identifier for an evaluation form, regardless of version

        :return: The context_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this AnalyticsEvaluation.
        A unique identifier for an evaluation form, regardless of version

        :param context_id: The context_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._context_id = context_id

    @property
    def form_name(self):
        """
        Gets the form_name of this AnalyticsEvaluation.
        Name of the evaluation form

        :return: The form_name of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._form_name

    @form_name.setter
    def form_name(self, form_name):
        """
        Sets the form_name of this AnalyticsEvaluation.
        Name of the evaluation form

        :param form_name: The form_name of this AnalyticsEvaluation.
        :type: str
        """
        
        self._form_name = form_name

    @property
    def calibration_id(self):
        """
        Gets the calibration_id of this AnalyticsEvaluation.
        The calibration id used for the purpose of training evaluators

        :return: The calibration_id of this AnalyticsEvaluation.
        :rtype: str
        """
        return self._calibration_id

    @calibration_id.setter
    def calibration_id(self, calibration_id):
        """
        Sets the calibration_id of this AnalyticsEvaluation.
        The calibration id used for the purpose of training evaluators

        :param calibration_id: The calibration_id of this AnalyticsEvaluation.
        :type: str
        """
        
        self._calibration_id = calibration_id

    @property
    def rescored(self):
        """
        Gets the rescored of this AnalyticsEvaluation.
        Whether this evaluation has ever been rescored

        :return: The rescored of this AnalyticsEvaluation.
        :rtype: bool
        """
        return self._rescored

    @rescored.setter
    def rescored(self, rescored):
        """
        Sets the rescored of this AnalyticsEvaluation.
        Whether this evaluation has ever been rescored

        :param rescored: The rescored of this AnalyticsEvaluation.
        :type: bool
        """
        
        self._rescored = rescored

    @property
    def deleted(self):
        """
        Gets the deleted of this AnalyticsEvaluation.
        Whether this evaluation has been deleted

        :return: The deleted of this AnalyticsEvaluation.
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """
        Sets the deleted of this AnalyticsEvaluation.
        Whether this evaluation has been deleted

        :param deleted: The deleted of this AnalyticsEvaluation.
        :type: bool
        """
        
        self._deleted = deleted

    @property
    def o_total_score(self):
        """
        Gets the o_total_score of this AnalyticsEvaluation.


        :return: The o_total_score of this AnalyticsEvaluation.
        :rtype: int
        """
        return self._o_total_score

    @o_total_score.setter
    def o_total_score(self, o_total_score):
        """
        Sets the o_total_score of this AnalyticsEvaluation.


        :param o_total_score: The o_total_score of this AnalyticsEvaluation.
        :type: int
        """
        
        self._o_total_score = o_total_score

    @property
    def o_total_critical_score(self):
        """
        Gets the o_total_critical_score of this AnalyticsEvaluation.


        :return: The o_total_critical_score of this AnalyticsEvaluation.
        :rtype: int
        """
        return self._o_total_critical_score

    @o_total_critical_score.setter
    def o_total_critical_score(self, o_total_critical_score):
        """
        Sets the o_total_critical_score of this AnalyticsEvaluation.


        :param o_total_critical_score: The o_total_critical_score of this AnalyticsEvaluation.
        :type: int
        """
        
        self._o_total_critical_score = o_total_critical_score

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LocationUpdateDefinition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LocationUpdateDefinition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'version': 'int',
            'state': 'str',
            'path': 'list[str]',
            'notes': 'str',
            'contact_user': 'str',
            'emergency_number': 'LocationEmergencyNumber',
            'address': 'LocationAddress'
        }

        self.attribute_map = {
            'name': 'name',
            'version': 'version',
            'state': 'state',
            'path': 'path',
            'notes': 'notes',
            'contact_user': 'contactUser',
            'emergency_number': 'emergencyNumber',
            'address': 'address'
        }

        self._name = None
        self._version = None
        self._state = None
        self._path = None
        self._notes = None
        self._contact_user = None
        self._emergency_number = None
        self._address = None

    @property
    def name(self):
        """
        Gets the name of this LocationUpdateDefinition.
        The name of the Location. Required for creates, not required for updates

        :return: The name of this LocationUpdateDefinition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LocationUpdateDefinition.
        The name of the Location. Required for creates, not required for updates

        :param name: The name of this LocationUpdateDefinition.
        :type: str
        """
        
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this LocationUpdateDefinition.
        Current version of the location

        :return: The version of this LocationUpdateDefinition.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this LocationUpdateDefinition.
        Current version of the location

        :param version: The version of this LocationUpdateDefinition.
        :type: int
        """
        
        self._version = version

    @property
    def state(self):
        """
        Gets the state of this LocationUpdateDefinition.
        Current activity status of the location.

        :return: The state of this LocationUpdateDefinition.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this LocationUpdateDefinition.
        Current activity status of the location.

        :param state: The state of this LocationUpdateDefinition.
        :type: str
        """
        allowed_values = ["active", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def path(self):
        """
        Gets the path of this LocationUpdateDefinition.
        A list of ancestor ids

        :return: The path of this LocationUpdateDefinition.
        :rtype: list[str]
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this LocationUpdateDefinition.
        A list of ancestor ids

        :param path: The path of this LocationUpdateDefinition.
        :type: list[str]
        """
        
        self._path = path

    @property
    def notes(self):
        """
        Gets the notes of this LocationUpdateDefinition.
        Notes for the location

        :return: The notes of this LocationUpdateDefinition.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this LocationUpdateDefinition.
        Notes for the location

        :param notes: The notes of this LocationUpdateDefinition.
        :type: str
        """
        
        self._notes = notes

    @property
    def contact_user(self):
        """
        Gets the contact_user of this LocationUpdateDefinition.
        The user id of the location contact

        :return: The contact_user of this LocationUpdateDefinition.
        :rtype: str
        """
        return self._contact_user

    @contact_user.setter
    def contact_user(self, contact_user):
        """
        Sets the contact_user of this LocationUpdateDefinition.
        The user id of the location contact

        :param contact_user: The contact_user of this LocationUpdateDefinition.
        :type: str
        """
        
        self._contact_user = contact_user

    @property
    def emergency_number(self):
        """
        Gets the emergency_number of this LocationUpdateDefinition.
        Emergency number for the location

        :return: The emergency_number of this LocationUpdateDefinition.
        :rtype: LocationEmergencyNumber
        """
        return self._emergency_number

    @emergency_number.setter
    def emergency_number(self, emergency_number):
        """
        Sets the emergency_number of this LocationUpdateDefinition.
        Emergency number for the location

        :param emergency_number: The emergency_number of this LocationUpdateDefinition.
        :type: LocationEmergencyNumber
        """
        
        self._emergency_number = emergency_number

    @property
    def address(self):
        """
        Gets the address of this LocationUpdateDefinition.
        Address of the location

        :return: The address of this LocationUpdateDefinition.
        :rtype: LocationAddress
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this LocationUpdateDefinition.
        Address of the location

        :param address: The address of this LocationUpdateDefinition.
        :type: LocationAddress
        """
        
        self._address = address

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class RecordingMessagingMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        RecordingMessagingMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'pcFrom': 'str',
            'from_user': 'User',
            'from_external_contact': 'ExternalContact',
            'to': 'str',
            'timestamp': 'datetime',
            'id': 'str',
            'message_text': 'str',
            'message_media_attachments': 'list[MessageMediaAttachment]',
            'message_sticker_attachments': 'list[MessageStickerAttachment]'
        }

        self.attribute_map = {
            'pcFrom': 'from',
            'from_user': 'fromUser',
            'from_external_contact': 'fromExternalContact',
            'to': 'to',
            'timestamp': 'timestamp',
            'id': 'id',
            'message_text': 'messageText',
            'message_media_attachments': 'messageMediaAttachments',
            'message_sticker_attachments': 'messageStickerAttachments'
        }

        self._pcFrom = None
        self._from_user = None
        self._from_external_contact = None
        self._to = None
        self._timestamp = None
        self._id = None
        self._message_text = None
        self._message_media_attachments = None
        self._message_sticker_attachments = None

    @property
    def pcFrom(self):
        """
        Gets the pcFrom of this RecordingMessagingMessage.


        :return: The pcFrom of this RecordingMessagingMessage.
        :rtype: str
        """
        return self._pcFrom

    @pcFrom.setter
    def pcFrom(self, pcFrom):
        """
        Sets the pcFrom of this RecordingMessagingMessage.


        :param pcFrom: The pcFrom of this RecordingMessagingMessage.
        :type: str
        """
        
        self._pcFrom = pcFrom

    @property
    def from_user(self):
        """
        Gets the from_user of this RecordingMessagingMessage.


        :return: The from_user of this RecordingMessagingMessage.
        :rtype: User
        """
        return self._from_user

    @from_user.setter
    def from_user(self, from_user):
        """
        Sets the from_user of this RecordingMessagingMessage.


        :param from_user: The from_user of this RecordingMessagingMessage.
        :type: User
        """
        
        self._from_user = from_user

    @property
    def from_external_contact(self):
        """
        Gets the from_external_contact of this RecordingMessagingMessage.


        :return: The from_external_contact of this RecordingMessagingMessage.
        :rtype: ExternalContact
        """
        return self._from_external_contact

    @from_external_contact.setter
    def from_external_contact(self, from_external_contact):
        """
        Sets the from_external_contact of this RecordingMessagingMessage.


        :param from_external_contact: The from_external_contact of this RecordingMessagingMessage.
        :type: ExternalContact
        """
        
        self._from_external_contact = from_external_contact

    @property
    def to(self):
        """
        Gets the to of this RecordingMessagingMessage.


        :return: The to of this RecordingMessagingMessage.
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """
        Sets the to of this RecordingMessagingMessage.


        :param to: The to of this RecordingMessagingMessage.
        :type: str
        """
        
        self._to = to

    @property
    def timestamp(self):
        """
        Gets the timestamp of this RecordingMessagingMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The timestamp of this RecordingMessagingMessage.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this RecordingMessagingMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param timestamp: The timestamp of this RecordingMessagingMessage.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def id(self):
        """
        Gets the id of this RecordingMessagingMessage.


        :return: The id of this RecordingMessagingMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RecordingMessagingMessage.


        :param id: The id of this RecordingMessagingMessage.
        :type: str
        """
        
        self._id = id

    @property
    def message_text(self):
        """
        Gets the message_text of this RecordingMessagingMessage.


        :return: The message_text of this RecordingMessagingMessage.
        :rtype: str
        """
        return self._message_text

    @message_text.setter
    def message_text(self, message_text):
        """
        Sets the message_text of this RecordingMessagingMessage.


        :param message_text: The message_text of this RecordingMessagingMessage.
        :type: str
        """
        
        self._message_text = message_text

    @property
    def message_media_attachments(self):
        """
        Gets the message_media_attachments of this RecordingMessagingMessage.


        :return: The message_media_attachments of this RecordingMessagingMessage.
        :rtype: list[MessageMediaAttachment]
        """
        return self._message_media_attachments

    @message_media_attachments.setter
    def message_media_attachments(self, message_media_attachments):
        """
        Sets the message_media_attachments of this RecordingMessagingMessage.


        :param message_media_attachments: The message_media_attachments of this RecordingMessagingMessage.
        :type: list[MessageMediaAttachment]
        """
        
        self._message_media_attachments = message_media_attachments

    @property
    def message_sticker_attachments(self):
        """
        Gets the message_sticker_attachments of this RecordingMessagingMessage.


        :return: The message_sticker_attachments of this RecordingMessagingMessage.
        :rtype: list[MessageStickerAttachment]
        """
        return self._message_sticker_attachments

    @message_sticker_attachments.setter
    def message_sticker_attachments(self, message_sticker_attachments):
        """
        Sets the message_sticker_attachments of this RecordingMessagingMessage.


        :param message_sticker_attachments: The message_sticker_attachments of this RecordingMessagingMessage.
        :type: list[MessageStickerAttachment]
        """
        
        self._message_sticker_attachments = message_sticker_attachments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationMessageEventTopicMessageMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationMessageEventTopicMessageMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'ConversationMessageEventTopicUriReference',
            'queue': 'ConversationMessageEventTopicUriReference',
            'team': 'ConversationMessageEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'ConversationMessageEventTopicErrorBody',
            'script': 'ConversationMessageEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'ConversationMessageEventTopicUriReference',
            'external_organization': 'ConversationMessageEventTopicUriReference',
            'wrapup': 'ConversationMessageEventTopicWrapup',
            'conversation_routing_data': 'ConversationMessageEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'ConversationMessageEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'messages': 'list[ConversationMessageEventTopicMessageDetails]',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'messages': 'messages',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._messages = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None

    @property
    def id(self):
        """
        Gets the id of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The id of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConversationMessageEventTopicMessageMediaParticipant.


        :param id: The id of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The name of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConversationMessageEventTopicMessageMediaParticipant.


        :param name: The name of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The address of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ConversationMessageEventTopicMessageMediaParticipant.


        :param address: The address of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param start_time: The start_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The connected_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param connected_time: The connected_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The end_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param end_time: The end_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_hold_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param start_hold_time: The start_hold_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The purpose of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this ConversationMessageEventTopicMessageMediaParticipant.


        :param purpose: The purpose of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The state of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ConversationMessageEventTopicMessageMediaParticipant.


        :param state: The state of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The direction of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this ConversationMessageEventTopicMessageMediaParticipant.


        :param direction: The direction of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The disconnect_type of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this ConversationMessageEventTopicMessageMediaParticipant.


        :param disconnect_type: The disconnect_type of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The held of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this ConversationMessageEventTopicMessageMediaParticipant.


        :param held: The held of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_required of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this ConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_required: The wrapup_required of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_prompt of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this ConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The user of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this ConversationMessageEventTopicMessageMediaParticipant.


        :param user: The user of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The queue of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this ConversationMessageEventTopicMessageMediaParticipant.


        :param queue: The queue of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The team of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this ConversationMessageEventTopicMessageMediaParticipant.


        :param team: The team of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The attributes of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ConversationMessageEventTopicMessageMediaParticipant.


        :param attributes: The attributes of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The error_info of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this ConversationMessageEventTopicMessageMediaParticipant.


        :param error_info: The error_info of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The script of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this ConversationMessageEventTopicMessageMediaParticipant.


        :param script: The script of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_skipped of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this ConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The alerting_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The provider of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this ConversationMessageEventTopicMessageMediaParticipant.


        :param provider: The provider of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The external_contact of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this ConversationMessageEventTopicMessageMediaParticipant.


        :param external_contact: The external_contact of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The external_organization of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this ConversationMessageEventTopicMessageMediaParticipant.


        :param external_organization: The external_organization of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this ConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup: The wrapup of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The conversation_routing_data of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this ConversationMessageEventTopicMessageMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The peer of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this ConversationMessageEventTopicMessageMediaParticipant.


        :param peer: The peer of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The screen_recording_state of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this ConversationMessageEventTopicMessageMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The flagged_reason of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this ConversationMessageEventTopicMessageMediaParticipant.


        :param flagged_reason: The flagged_reason of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The journey_context of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: ConversationMessageEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this ConversationMessageEventTopicMessageMediaParticipant.


        :param journey_context: The journey_context of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: ConversationMessageEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param start_acw_time: The start_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The end_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.


        :param end_acw_time: The end_acw_time of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def messages(self):
        """
        Gets the messages of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The messages of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: list[ConversationMessageEventTopicMessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this ConversationMessageEventTopicMessageMediaParticipant.


        :param messages: The messages of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: list[ConversationMessageEventTopicMessageDetails]
        """
        
        self._messages = messages

    @property
    def type(self):
        """
        Gets the type of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The type of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ConversationMessageEventTopicMessageMediaParticipant.


        :param type: The type of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["UNKNOWN", "SMS", "TWITTER", "FACEBOOK", "LINE", "VIBER", "WECHAT", "WHATSAPP", "TELEGRAM", "KAKAO", "WEBMESSAGING"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The recipient_country of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this ConversationMessageEventTopicMessageMediaParticipant.


        :param recipient_country: The recipient_country of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this ConversationMessageEventTopicMessageMediaParticipant.


        :return: The recipient_type of this ConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this ConversationMessageEventTopicMessageMediaParticipant.


        :param recipient_type: The recipient_type of this ConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._recipient_type = recipient_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuRescheduleResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuRescheduleResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'generation_results': 'ScheduleGenerationResult',
            'generation_results_download_url': 'str',
            'headcount_forecast': 'BuHeadcountForecast',
            'headcount_forecast_download_url': 'str',
            'agent_schedules': 'list[BuRescheduleAgentScheduleResult]'
        }

        self.attribute_map = {
            'generation_results': 'generationResults',
            'generation_results_download_url': 'generationResultsDownloadUrl',
            'headcount_forecast': 'headcountForecast',
            'headcount_forecast_download_url': 'headcountForecastDownloadUrl',
            'agent_schedules': 'agentSchedules'
        }

        self._generation_results = None
        self._generation_results_download_url = None
        self._headcount_forecast = None
        self._headcount_forecast_download_url = None
        self._agent_schedules = None

    @property
    def generation_results(self):
        """
        Gets the generation_results of this BuRescheduleResult.
        The generation results.  Note the result will always be delivered via the downloadUrl; however the schema is included for documentation

        :return: The generation_results of this BuRescheduleResult.
        :rtype: ScheduleGenerationResult
        """
        return self._generation_results

    @generation_results.setter
    def generation_results(self, generation_results):
        """
        Sets the generation_results of this BuRescheduleResult.
        The generation results.  Note the result will always be delivered via the downloadUrl; however the schema is included for documentation

        :param generation_results: The generation_results of this BuRescheduleResult.
        :type: ScheduleGenerationResult
        """
        
        self._generation_results = generation_results

    @property
    def generation_results_download_url(self):
        """
        Gets the generation_results_download_url of this BuRescheduleResult.
        The download URL from which to fetch the generation results for the rescheduling run

        :return: The generation_results_download_url of this BuRescheduleResult.
        :rtype: str
        """
        return self._generation_results_download_url

    @generation_results_download_url.setter
    def generation_results_download_url(self, generation_results_download_url):
        """
        Sets the generation_results_download_url of this BuRescheduleResult.
        The download URL from which to fetch the generation results for the rescheduling run

        :param generation_results_download_url: The generation_results_download_url of this BuRescheduleResult.
        :type: str
        """
        
        self._generation_results_download_url = generation_results_download_url

    @property
    def headcount_forecast(self):
        """
        Gets the headcount_forecast of this BuRescheduleResult.
        The headcount forecast.  Note the result will always be delivered via the downloadUrl; however the schema is included for documentation

        :return: The headcount_forecast of this BuRescheduleResult.
        :rtype: BuHeadcountForecast
        """
        return self._headcount_forecast

    @headcount_forecast.setter
    def headcount_forecast(self, headcount_forecast):
        """
        Sets the headcount_forecast of this BuRescheduleResult.
        The headcount forecast.  Note the result will always be delivered via the downloadUrl; however the schema is included for documentation

        :param headcount_forecast: The headcount_forecast of this BuRescheduleResult.
        :type: BuHeadcountForecast
        """
        
        self._headcount_forecast = headcount_forecast

    @property
    def headcount_forecast_download_url(self):
        """
        Gets the headcount_forecast_download_url of this BuRescheduleResult.
        The download URL from which to fetch the headcount forecast for the rescheduling run

        :return: The headcount_forecast_download_url of this BuRescheduleResult.
        :rtype: str
        """
        return self._headcount_forecast_download_url

    @headcount_forecast_download_url.setter
    def headcount_forecast_download_url(self, headcount_forecast_download_url):
        """
        Sets the headcount_forecast_download_url of this BuRescheduleResult.
        The download URL from which to fetch the headcount forecast for the rescheduling run

        :param headcount_forecast_download_url: The headcount_forecast_download_url of this BuRescheduleResult.
        :type: str
        """
        
        self._headcount_forecast_download_url = headcount_forecast_download_url

    @property
    def agent_schedules(self):
        """
        Gets the agent_schedules of this BuRescheduleResult.
        List of download links for agent schedules produced by the rescheduling run

        :return: The agent_schedules of this BuRescheduleResult.
        :rtype: list[BuRescheduleAgentScheduleResult]
        """
        return self._agent_schedules

    @agent_schedules.setter
    def agent_schedules(self, agent_schedules):
        """
        Sets the agent_schedules of this BuRescheduleResult.
        List of download links for agent schedules produced by the rescheduling run

        :param agent_schedules: The agent_schedules of this BuRescheduleResult.
        :type: list[BuRescheduleAgentScheduleResult]
        """
        
        self._agent_schedules = agent_schedules

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SurveyAssignment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SurveyAssignment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'survey_form': 'PublishedSurveyFormReference',
            'flow': 'DomainEntityRef',
            'invite_time_interval': 'str',
            'sending_user': 'str',
            'sending_domain': 'str'
        }

        self.attribute_map = {
            'survey_form': 'surveyForm',
            'flow': 'flow',
            'invite_time_interval': 'inviteTimeInterval',
            'sending_user': 'sendingUser',
            'sending_domain': 'sendingDomain'
        }

        self._survey_form = None
        self._flow = None
        self._invite_time_interval = None
        self._sending_user = None
        self._sending_domain = None

    @property
    def survey_form(self):
        """
        Gets the survey_form of this SurveyAssignment.
        The survey form used for this survey.

        :return: The survey_form of this SurveyAssignment.
        :rtype: PublishedSurveyFormReference
        """
        return self._survey_form

    @survey_form.setter
    def survey_form(self, survey_form):
        """
        Sets the survey_form of this SurveyAssignment.
        The survey form used for this survey.

        :param survey_form: The survey_form of this SurveyAssignment.
        :type: PublishedSurveyFormReference
        """
        
        self._survey_form = survey_form

    @property
    def flow(self):
        """
        Gets the flow of this SurveyAssignment.
        The URI reference to the flow associated with this survey.

        :return: The flow of this SurveyAssignment.
        :rtype: DomainEntityRef
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """
        Sets the flow of this SurveyAssignment.
        The URI reference to the flow associated with this survey.

        :param flow: The flow of this SurveyAssignment.
        :type: DomainEntityRef
        """
        
        self._flow = flow

    @property
    def invite_time_interval(self):
        """
        Gets the invite_time_interval of this SurveyAssignment.
        An ISO 8601 repeated interval consisting of the number of repetitions, the start datetime, and the interval (e.g. R2/2018-03-01T13:00:00Z/P1M10DT2H30M). Total duration must not exceed 90 days.

        :return: The invite_time_interval of this SurveyAssignment.
        :rtype: str
        """
        return self._invite_time_interval

    @invite_time_interval.setter
    def invite_time_interval(self, invite_time_interval):
        """
        Sets the invite_time_interval of this SurveyAssignment.
        An ISO 8601 repeated interval consisting of the number of repetitions, the start datetime, and the interval (e.g. R2/2018-03-01T13:00:00Z/P1M10DT2H30M). Total duration must not exceed 90 days.

        :param invite_time_interval: The invite_time_interval of this SurveyAssignment.
        :type: str
        """
        
        self._invite_time_interval = invite_time_interval

    @property
    def sending_user(self):
        """
        Gets the sending_user of this SurveyAssignment.
        User together with sendingDomain used to send email, null to use no-reply

        :return: The sending_user of this SurveyAssignment.
        :rtype: str
        """
        return self._sending_user

    @sending_user.setter
    def sending_user(self, sending_user):
        """
        Sets the sending_user of this SurveyAssignment.
        User together with sendingDomain used to send email, null to use no-reply

        :param sending_user: The sending_user of this SurveyAssignment.
        :type: str
        """
        
        self._sending_user = sending_user

    @property
    def sending_domain(self):
        """
        Gets the sending_domain of this SurveyAssignment.
        Validated email domain, required

        :return: The sending_domain of this SurveyAssignment.
        :rtype: str
        """
        return self._sending_domain

    @sending_domain.setter
    def sending_domain(self, sending_domain):
        """
        Sets the sending_domain of this SurveyAssignment.
        Validated email domain, required

        :param sending_domain: The sending_domain of this SurveyAssignment.
        :type: str
        """
        
        self._sending_domain = sending_domain

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class OrgOAuthClient(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrgOAuthClient - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'created_by': 'DomainEntityRef',
            'modified_by': 'DomainEntityRef',
            'authorized_grant_type': 'str',
            'scope': 'list[str]',
            'role_divisions': 'list[RoleDivision]',
            'state': 'str',
            'date_to_delete': 'datetime',
            'organization': 'NamedEntity'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'created_by': 'createdBy',
            'modified_by': 'modifiedBy',
            'authorized_grant_type': 'authorizedGrantType',
            'scope': 'scope',
            'role_divisions': 'roleDivisions',
            'state': 'state',
            'date_to_delete': 'dateToDelete',
            'organization': 'organization'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._created_by = None
        self._modified_by = None
        self._authorized_grant_type = None
        self._scope = None
        self._role_divisions = None
        self._state = None
        self._date_to_delete = None
        self._organization = None

    @property
    def id(self):
        """
        Gets the id of this OrgOAuthClient.
        The globally unique identifier for the object.

        :return: The id of this OrgOAuthClient.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OrgOAuthClient.
        The globally unique identifier for the object.

        :param id: The id of this OrgOAuthClient.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OrgOAuthClient.
        The name of the OAuth client.

        :return: The name of this OrgOAuthClient.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrgOAuthClient.
        The name of the OAuth client.

        :param name: The name of this OrgOAuthClient.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this OrgOAuthClient.
        Date this client was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this OrgOAuthClient.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this OrgOAuthClient.
        Date this client was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this OrgOAuthClient.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this OrgOAuthClient.
        Date this client was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this OrgOAuthClient.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this OrgOAuthClient.
        Date this client was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this OrgOAuthClient.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def created_by(self):
        """
        Gets the created_by of this OrgOAuthClient.
        User that created this client

        :return: The created_by of this OrgOAuthClient.
        :rtype: DomainEntityRef
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this OrgOAuthClient.
        User that created this client

        :param created_by: The created_by of this OrgOAuthClient.
        :type: DomainEntityRef
        """
        
        self._created_by = created_by

    @property
    def modified_by(self):
        """
        Gets the modified_by of this OrgOAuthClient.
        User that last modified this client

        :return: The modified_by of this OrgOAuthClient.
        :rtype: DomainEntityRef
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this OrgOAuthClient.
        User that last modified this client

        :param modified_by: The modified_by of this OrgOAuthClient.
        :type: DomainEntityRef
        """
        
        self._modified_by = modified_by

    @property
    def authorized_grant_type(self):
        """
        Gets the authorized_grant_type of this OrgOAuthClient.
        The OAuth Grant/Client type supported by this client. Code Authorization Grant/Client type - Preferred client type where the Client ID and Secret are required to create tokens. Used where the secret can be secured. PKCE-Enabled Code Authorization grant type - Code grant type which requires PKCE challenge and verifier to create tokens. Used in public clients for increased security. Implicit grant type - Client ID only is required to create tokens. Used in browser and mobile apps where the secret can not be secured. SAML2-Bearer extension grant type - SAML2 assertion provider for user authentication at the token endpoint. Client Credential grant type - Used to created access tokens that are tied only to the client. 

        :return: The authorized_grant_type of this OrgOAuthClient.
        :rtype: str
        """
        return self._authorized_grant_type

    @authorized_grant_type.setter
    def authorized_grant_type(self, authorized_grant_type):
        """
        Sets the authorized_grant_type of this OrgOAuthClient.
        The OAuth Grant/Client type supported by this client. Code Authorization Grant/Client type - Preferred client type where the Client ID and Secret are required to create tokens. Used where the secret can be secured. PKCE-Enabled Code Authorization grant type - Code grant type which requires PKCE challenge and verifier to create tokens. Used in public clients for increased security. Implicit grant type - Client ID only is required to create tokens. Used in browser and mobile apps where the secret can not be secured. SAML2-Bearer extension grant type - SAML2 assertion provider for user authentication at the token endpoint. Client Credential grant type - Used to created access tokens that are tied only to the client. 

        :param authorized_grant_type: The authorized_grant_type of this OrgOAuthClient.
        :type: str
        """
        allowed_values = ["CODE", "CODE_PKCE", "TOKEN", "SAML2BEARER", "PASSWORD", "CLIENT_CREDENTIALS"]
        if authorized_grant_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for authorized_grant_type -> " + authorized_grant_type)
            self._authorized_grant_type = "outdated_sdk_version"
        else:
            self._authorized_grant_type = authorized_grant_type

    @property
    def scope(self):
        """
        Gets the scope of this OrgOAuthClient.
        The scope requested by this client. Scopes only apply to clients not using the client_credential grant

        :return: The scope of this OrgOAuthClient.
        :rtype: list[str]
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this OrgOAuthClient.
        The scope requested by this client. Scopes only apply to clients not using the client_credential grant

        :param scope: The scope of this OrgOAuthClient.
        :type: list[str]
        """
        
        self._scope = scope

    @property
    def role_divisions(self):
        """
        Gets the role_divisions of this OrgOAuthClient.
        Set of roles and their corresponding divisions associated with this client. Roles and divisions only apply to clients using the client_credential grant

        :return: The role_divisions of this OrgOAuthClient.
        :rtype: list[RoleDivision]
        """
        return self._role_divisions

    @role_divisions.setter
    def role_divisions(self, role_divisions):
        """
        Sets the role_divisions of this OrgOAuthClient.
        Set of roles and their corresponding divisions associated with this client. Roles and divisions only apply to clients using the client_credential grant

        :param role_divisions: The role_divisions of this OrgOAuthClient.
        :type: list[RoleDivision]
        """
        
        self._role_divisions = role_divisions

    @property
    def state(self):
        """
        Gets the state of this OrgOAuthClient.
        The state of the OAuth client. Active: The OAuth client can be used to create access tokens. This is the default state. Disabled: Access tokens created by the client are invalid and new ones cannot be created. Inactive: Access tokens cannot be created with this OAuth client and it will be deleted.

        :return: The state of this OrgOAuthClient.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this OrgOAuthClient.
        The state of the OAuth client. Active: The OAuth client can be used to create access tokens. This is the default state. Disabled: Access tokens created by the client are invalid and new ones cannot be created. Inactive: Access tokens cannot be created with this OAuth client and it will be deleted.

        :param state: The state of this OrgOAuthClient.
        :type: str
        """
        allowed_values = ["active", "disabled", "inactive"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def date_to_delete(self):
        """
        Gets the date_to_delete of this OrgOAuthClient.
        The time at which this client will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_to_delete of this OrgOAuthClient.
        :rtype: datetime
        """
        return self._date_to_delete

    @date_to_delete.setter
    def date_to_delete(self, date_to_delete):
        """
        Sets the date_to_delete of this OrgOAuthClient.
        The time at which this client will be deleted. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_to_delete: The date_to_delete of this OrgOAuthClient.
        :type: datetime
        """
        
        self._date_to_delete = date_to_delete

    @property
    def organization(self):
        """
        Gets the organization of this OrgOAuthClient.
        The  oauth client's organization.

        :return: The organization of this OrgOAuthClient.
        :rtype: NamedEntity
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this OrgOAuthClient.
        The  oauth client's organization.

        :param organization: The organization of this OrgOAuthClient.
        :type: NamedEntity
        """
        
        self._organization = organization

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

